:root {
  --primary-color: #2c3e50;
  --secondary-color: #3498db;
  --accent-color: #e74c3c;
  --background-color: #f5f6fa;
  --text-color: #2c3e50;
  --border-radius: 8px;
  --shadow: 0 2px 4px rgba(0,0,0,0.1);
}

* {
  margin: 0;
  padding: 0;
  box-sizing: border-box;
}

body {
  font-family: 'Segoe UI', system-ui, sans-serif;
  line-height: 1.6;
  color: var(--text-color);
  background: var(--background-color);
}

header {
  background: var(--primary-color);
  color: white;
  padding: 1rem;
  box-shadow: var(--shadow);
}

h1 {
  font-size: 2rem;
  margin-bottom: 1rem;
}

.search-container {
  display: flex;
  gap: 1rem;
  margin: 1rem 0;
}

input[type="search"],
select,
textarea {
  padding: 0.5rem;
  border: 1px solid #ddd;
  border-radius: var(--border-radius);
  width: 100%;
}

.primary-btn {
  background: var(--secondary-color);
  color: white;
  border: none;
  padding: 0.5rem 1rem;
  border-radius: var(--border-radius);
  cursor: pointer;
  transition: background 0.3s ease;
}

.primary-btn:hover {
  background: #2980b9;
}

.secondary-btn {
  background: transparent;
  border: 1px solid var(--secondary-color);
  color: var(--secondary-color);
  padding: 0.5rem 1rem;
  border-radius: var(--border-radius);
  cursor: pointer;
  transition: all 0.3s ease;
}

.secondary-btn:hover {
  background: var(--secondary-color);
  color: white;
}

.logs-container {
  padding: 1rem;
  display: grid;
  gap: 1rem;
  grid-template-columns: repeat(auto-fill, minmax(300px, 1fr));
}

.log-card {
  background: white;
  padding: 1rem;
  border-radius: var(--border-radius);
  box-shadow: var(--shadow);
  transition: transform 0.3s ease;
}

.log-card:hover {
  transform: translateY(-2px);
}

.modal {
  border: none;
  border-radius: var(--border-radius);
  padding: 2rem;
  max-width: 600px;
  width: 90%;
}

.form-group {
  margin-bottom: 1rem;
}

.button-group {
  display: flex;
  gap: 1rem;
  justify-content: flex-end;
  margin-top: 1rem;
}

.stats-container {
  background: white;
  padding: 1rem;
  margin: 1rem;
  border-radius: var(--border-radius);
  box-shadow: var(--shadow);
}

@media (max-width: 768px) {
  .search-container {
    flex-direction: column;
  }
  
  .logs-container {
    grid-template-columns: 1fr;
  }
}
